==> JVPC-0.93.zip: JVPC-0.93/jvpc/MapShip.java <==
// File: MapShip.java

package jvpc.jvpc;

import java.awt.*;
import kero.util.*;
import jvpc.vga.*;

/**
 * @author Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since 4 III 2001
 * @version 4 III 2001
 */
public class MapShip extends MapLocated {
    static Color shipStatusColorMap[] = colorMap;

    Ship ship;

    public MapShip(Map m, Ship e) {
	map = m;
	ship = e;
    }

    public Color getColor() {
	Color c;
	int owner = ship.getOwner();
	if ((owner == 0) || (owner == UNKNOWN)) {
	    c = Color.gray;
	} else {
	    switch (map.colorModel) {
	    case 0:
		int shipstatus = map.universe.getPlayer(owner).getShipStatus();
		c = shipStatusColorMap[shipstatus];
		break;
	    case 1:
		c = MapLocated.playerColorMap[owner];
		break;
	    default:
		Assert.assert(false);
		c = Color.white;
	    }
	}
	    return c;
    }

    public String getString() {
	int shiptype=ship.getHulltype();
	String label;
	switch (map.shipLabel) {
	case 0:
	    label = "s" + ship.getId();
	    break;
	case 1:
	    if (shiptype==UNKNOWN) {
		label = "hulltype unknown";
	    } else {
		Hull hull=map.universe.getGame().getHull(shiptype);
		label = hull.getShortName();
	    }
	    break;
	case 2:
	    label = ship.getName();
	    if (label == null) label="?";
	    break;
	case 3:
	    label = ship.toString(map.shipstring);
	    break;
	default:
	    label = "??";
	    Assert.assert(false);
	    break;
	}
	return label;
    }

    public void update(Graphics g, int x, int y) {
	int size = (int)Math.ceil(map.zoom * 1.5);
	size += 2;
	if (!ship.getUniverse().isActive(ship.getOwner())) size += 2;
	int wayX=x, wayY=y;
	if (map.drawShipWaypoints) {
	    if (ship.getDX() != UNKNOWN) {
		wayX = map.toMapX(ship.getX()+ship.getDX());
		wayY = map.toMapY(ship.getY()+ship.getDY());
		if ((x<0) && (wayX<0)) return;
		//if ((x>=dim.width) && (wayX>=dim.width)) return;
		if ((y<0) && (wayY<0)) return;
		//if ((y>=dim.height) && (wayY>=dim.height)) return;
	    }
	}
	g.drawOval(x-size/2, y-size/2, size, size);
	if (map.drawShipWaypoints) {
	    g.drawLine(x, y, wayX, wayY);
	}
    }
}

==> JVPC-0.94.zip: JVPC-0.94/jvpc/MapShip.java <==
// File: MapShip.java

package jvpc.jvpc;

import java.awt.*;
import kero.util.*;
import jvpc.vga.*;

/**
 * @author Kero van Gelder
 * @copyright Kero van Gelder (the GNU General Public License applies)
 * @since 4 III 2001
 * @version 4 III 2001
 */
public class MapShip extends MapLocated {
    static Color shipStatusColorMap[] = colorMap;

    Ship ship;

    public MapShip(Map m, Ship e) {
	map = m;
	ship = e;
    }

    public Color getColor() {
	Color c;
	int owner = ship.getOwner();
	if ((owner == 0) || (owner == UNKNOWN)) {
	    c = Color.gray;
	} else {
	    switch (map.colorModel) {
	    case 0:
		int shipstatus = map.universe.getPlayer(owner).getShipStatus();
		c = shipStatusColorMap[shipstatus];
		break;
	    case 1:
		c = MapLocated.playerColorMap[owner];
		break;
	    default:
		Assert.assert(false);
		c = Color.white;
	    }
	}
	    return c;
    }

    public String getString() {
	int shiptype=ship.getHulltype();
	String label;
	switch (map.shipLabel) {
	case 0:
	    label = "s" + ship.getId();
	    break;
	case 1:
	    if (shiptype==UNKNOWN) {
		label = "hulltype unknown";
	    } else {
		Hull hull=map.universe.getGame().getHull(shiptype);
		label = hull.getShortName();
	    }
	    break;
	case 2:
	    label = ship.getName();
	    if (label == null) label="?";
	    break;
	case 3:
	    label = ship.toString(map.shipstring);
	    break;
	default:
	    label = "??";
	    Assert.assert(false);
	    break;
	}
	return label;
    }

    public void update(Graphics g, int x, int y) {
	int size = ((int)Math.ceil(map.zoom * 1.5)) / 2 * 2 + 1;
	size += 2;
	if (size < 4) size = 4;  // fits better with planets-drawRect :/
	if (!ship.getUniverse().isActive(ship.getOwner())) size += 2;
	int wayX=x, wayY=y;
	if (map.drawShipWaypoints) {
	}
	g.drawOval(x-size/2, y-size/2, size, size);
	if (map.drawShipWaypoints) {
	    if (ship.getDX() != UNKNOWN &&
	      (ship.getDX() != 0 || ship.getDY() != 0)) {
		wayX = map.toMapX(ship.getX()+ship.getDX());
		wayY = map.toMapY(ship.getY()+ship.getDY());
		if ((x<0) && (wayX<0)) return;
		//if ((x>=dim.width) && (wayX>=dim.width)) return;
		if ((y<0) && (wayY<0)) return;
		//if ((y>=dim.height) && (wayY>=dim.height)) return;
		g.drawLine(x, y, wayX, wayY);
	    }
	}
    }
}
